pub trait ArrayDivAssign<T, const N: usize>: ArrayMeet<T, N> {
// Required methods
const fn div_assign_all<Rhs>(&mut self, rhs: Rhs)
where T: DivAssign<Rhs>,
Rhs: Copy;
const async fn div_assign_all_async<Rhs>(&mut self, rhs: Rhs)
where T: DivAssign<Rhs>,
Rhs: Copy;
const fn div_assign_each<Rhs>(&mut self, rhs: Rhs)
where T: DivAssign<Rhs::Elem>,
Rhs: ArrayForm<N>;
const async fn div_assign_each_async<Rhs>(&mut self, rhs: Rhs)
where T: DivAssign<Rhs::Elem>,
Rhs: ArrayForm<N>;
}Required Methods
Sourceconst fn div_assign_all<Rhs>(&mut self, rhs: Rhs)
const fn div_assign_all<Rhs>(&mut self, rhs: Rhs)
Sourceconst async fn div_assign_all_async<Rhs>(&mut self, rhs: Rhs)
const async fn div_assign_all_async<Rhs>(&mut self, rhs: Rhs)
Asynchronously applies the /= operator to all elements, copying the operand for each operation.
This way, each operation is a seperate async task that may be executed in parallel, but with some extra overhead.
Examples
use array__ops::ops::*;
let mut a = [0, 1, 2, 3, 4, 5, 6, 7];
a.div_assign_all_async(2).await;
assert_eq!(a, [0, 0, 1, 1, 2, 2, 3, 3]);Sourceconst fn div_assign_each<Rhs>(&mut self, rhs: Rhs)
const fn div_assign_each<Rhs>(&mut self, rhs: Rhs)
const async fn div_assign_each_async<Rhs>(&mut self, rhs: Rhs)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.